% Znázornenie harmonického obsahu impulzového singálu. 
% Výpočty podľa analyticky odvodených vzorcov
% Meňte doby trvania impulzu T1 voči T a sledujte obsah vyšších HZ

clc, clear
A=1; T=0.125; T1=T/5 % doba periódy T=0.125 s (f=8 Hz). Impulz T1=T/5
pocet = 30 % pocet zobrazovaných HZ

% Výpočet Fourierových koeficientov 
a0_2=A*T1/T;  
n=1:pocet; 
an=A*sin(2*pi*n*T1/T)./(n*pi);    % an
bn=A*(1-cos(2*pi*n*T1/T))./(n*pi);% bn
fin=atan2(bn,an);                 % fazy
An=sqrt(an.*an+bn.*bn);           % amplitudy
fn=n/T          % frekvencia n-tej harmonickej

figure(1)
subplot(221) % graf amplitudoveho spektra
    stem([0 fn],[a0_2 An],'filled'), grid 
    xlabel('\rightarrow f [Hz]') 
    ylabel('\rightarrow an/A') 
    title('Amplitudove spektrum') 

subplot(222) % graf fazoveho spektra
    stem([0 fn],[0 fin*180/pi]),grid 
    xlabel('\rightarrow f [Hz]') 
    ylabel('\rightarrow \phi [°]') 
    title('Fazove spektrum')

subplot(223)
    bar(n,An,0.2,'m')
    hold on, bar(0,a0_2,0.2,'m'),grid
    xlabel('\rightarrow n') 
    ylabel('\rightarrow an/A') 
    title('Amplitudove spektrum') 

subplot(224)
    bar(n,fin,0.2,'m')
    hold on, bar(0,0,0.2,'m'),grid
    xlabel('\rightarrow n') 
    ylabel('\rightarrow \phi [°]') 
    title('Fazove spektrum')

% Syntéza priebehu f(t)
figure(2)
t=0:pi/200:2*pi;  % časový interval 
ft=0;      % súčtová bunka
for n=1:pocet
    ft=ft+an(n).*cos(n*t)+bn(n).*sin(n*t)
end
ft=a0_2+ft; % pripočítanie js zložky
plot(t,ft,'LineWidth',1.5), grid on, title("Syntéza obdĺžnik. signálu z "+pocet+" HZ")
   xlabel('\rightarrow \rightarrowt [rad/s]'), ylabel('\rightarrow f(t)')

